@@ -1,7 +1,7 @@
 /**
  * HTTP/HTTPS client support
  *
- * Copyright (C) 2000-2007 by
+ * Copyright (C) 2000-2010 by
  * Jeffrey Fulmer - <jeff@joedog.org>, et al. 
  * This file is distributed as part of Siege 
  *
@@ -42,6 +42,7 @@
  */
 private BOOLEAN http_request(CONN *C, URL *U, CLIENT *c);
 private void increment_failures();
+private int  __select_color(int code);
 
 #ifdef  SIGNAL_CLIENT_PLATFORM
 static void signal_handler( int i );
@@ -112,13 +113,13 @@ start_routine(CLIENT *client)
   #endif
     pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, &state);
 #endif/*SIGNAL_CLIENT_PLATFORM*/ 
-  if(my.login == TRUE){
-    http_request(C, add_url(my.loginurl, 0), client);
+  if (my.login == TRUE) {
+    http_request(C, add_url(array_next(my.lurl), 0), client);
   }
 
-  for( x = 0, y = 0; x < my.reps; x++, y++ ){
-    x = (( my.secs > 0 ) && (( my.reps <= 0 )||( my.reps == MAXREPS))) ? 0 : x;
-    if( my.internet == TRUE ){
+  for (x = 0, y = 0; x < my.reps; x++, y++) {
+    x = ((my.secs > 0) && ((my.reps <= 0)||(my.reps == MAXREPS))) ? 0 : x;
+    if (my.internet == TRUE) {
       y = (unsigned int) (((double)pthread_rand_np(&(client->rand_r_SEED)) /
                           ((double)RAND_MAX + 1) * my.length ) + .5); 
       y = (y >= my.length)?my.length-1:y;
@@ -129,26 +130,26 @@ start_routine(CLIENT *client)
        * with clean slate, ie. reset (delete) cookies (eg. to let a new
        * session start)
        */
-      if( y >= my.length ){
+      if (y >= my.length) {
         y = 0;
-        if( my.expire ){
+        if (my.expire) {
           delete_all_cookies(pthread_self());
         }
       }
     }
-    if(y >= my.length || y < 0){ 
+    if (y >= my.length || y < 0) { 
       printf("y out of bounds: %d >= %d", y, my.length); 
       y = 0; 
     }
 
-    if(client->U[y] != NULL && client->U[y]->hostname != NULL){
+    if (client->U[y] != NULL && client->U[y]->hostname != NULL) {
       client->auth.bids.www = 0; /* reset */
-      if((ret = http_request(C, client->U[y], client))==FALSE){
+      if ((ret = http_request(C, client->U[y], client))==FALSE) {
         increment_failures();
       }
     }
  
-    if(my.failures > 0 && my.failed >= my.failures){
+    if (my.failures > 0 && my.failed >= my.failures) {
       break;
     }
   }
@@ -160,7 +161,7 @@ start_routine(CLIENT *client)
    */
   pthread_cleanup_pop(0);
   #endif/*SIGNAL_CLIENT_PLATFORM*/ 
-  if(C->sock >= 0){
+  if (C->sock >= 0){
     C->connection.reuse = 0;    
     socket_close(C);
   }
@@ -223,9 +224,10 @@ http_request(CONN *C, URL *U, CLIENT *client)
   C->auth.type.proxy      = client->auth.type.proxy;
   memset(C->buffer, 0, sizeof(C->buffer));
 
-  if(U->protocol == UNSUPPORTED){ 
-    if(my.verbose && !my.get){
-      printf(
+  if (U->protocol == UNSUPPORTED) { 
+    if (my.verbose && !my.get) {
+      NOTIFY ( 
+        ERROR,
         "%s %d %6.2f secs: %7d bytes ==> %s\n",
         "UNSPPRTD", 501, 0.00, 0, "PROTOCOL NOT SUPPORTED BY SIEGE" 
       );
@@ -233,7 +235,7 @@ http_request(CONN *C, URL *U, CLIENT *client)
     return FALSE;
   }
 
-  if(my.delay){
+  if (my.delay) {
     pthread_sleep_np(
      (unsigned int) (((double)pthread_rand_np(&(client->rand_r_SEED)) /
                      ((double)RAND_MAX + 1) * my.delay ) + .5) 
@@ -246,42 +248,48 @@ http_request(CONN *C, URL *U, CLIENT *client)
   start = times(&t_start);  
 
   debug( 
-    "attempting connection to %s:%d\n", 
+    "%s:%d attempting connection to %s:%d", 
+    __FILE__, __LINE__,
     (my.proxy.required==TRUE)?my.proxy.hostname:U->hostname,
     (my.proxy.required==TRUE)?my.proxy.port:U->port 
   ); 
 
-  if(!C->connection.reuse || C->connection.status == 0){
-    if(my.proxy.required){
-      debug("client.c:%d new_socket: %s:%d", __LINE__, my.proxy.hostname, my.proxy.port); 
+  if (!C->connection.reuse || C->connection.status == 0) {
+    if (my.proxy.required) {
+      debug("%s:%d creating new socket:     %s:%d", __FILE__, __LINE__, my.proxy.hostname, my.proxy.port); 
       C->sock = new_socket(C, my.proxy.hostname, my.proxy.port);
     } else {
-      debug("client.c:%d new_socket: %s:%d", __LINE__, U->hostname, U->port); 
+      debug("%s:%d creating new socket:     %s:%d", __FILE__, __LINE__, U->hostname, U->port); 
       C->sock = new_socket(C, U->hostname, U->port);
     }
   }
 
-  if(my.keepalive){
+  if (my.keepalive) {
     C->connection.reuse = TRUE;
   }
 
-  if(C->sock < 0){
+  if (C->sock < 0) {
     debug(
-      "connection failed. erro %d(%s)",errno,strerror(errno)
+      "%s:%d connection failed. error %d(%s)",__FILE__, __LINE__, errno,strerror(errno)
     ); 
     socket_close(C);
     return FALSE;
   } 
 
-  debug("%s:%d connection made: %d", __FILE__, __LINE__, C->sock); 
+  debug(
+    "%s:%d good socket connection:  %s:%d", 
+    __FILE__, __LINE__,
+    (my.proxy.required)?my.proxy.hostname:U->hostname,
+    (my.proxy.required)?my.proxy.port:U->port
+  ); 
 
-  if(C->prot == HTTPS){
-    if(my.proxy.required){
+  if (C->prot == HTTPS) {
+    if (my.proxy.required) {
       https_tunnel_request(C, U->hostname, U->port);
       https_tunnel_response(C);
     }
     C->encrypt = TRUE;
-    if(SSL_initialize(C)==FALSE){
+    if (SSL_initialize(C)==FALSE) {
       return FALSE;
     }
   }
@@ -289,14 +297,14 @@ http_request(CONN *C, URL *U, CLIENT *client)
   /**
    * write to socket with a POST or GET
    */
-  if(U->calltype == URL_POST){ 
-    if((http_post(C, U)) < 0){
+  if (U->calltype == URL_POST) { 
+    if ((http_post(C, U)) < 0) {
       C->connection.reuse = 0;
       socket_close(C);
       return FALSE;
     }
   } else { 
-    if((http_get(C, U)) < 0){
+    if ((http_get(C, U)) < 0) {
       C->connection.reuse = 0;
       socket_close(C);
       return FALSE;
@@ -305,20 +313,20 @@ http_request(CONN *C, URL *U, CLIENT *client)
   /**
    * read from socket and collect statistics.
    */
-  if((head = http_read_headers(C, U))==NULL){
+  if ((head = http_read_headers(C, U))==NULL) {
     C->connection.reuse = 0; 
     socket_close(C); 
-    debug("NULL headers: %s:%d", __FILE__, __LINE__);
+    debug("%s:%d NULL headers", __FILE__, __LINE__);
     return FALSE; 
   }
 
   bytes = http_read(C); 
 
-  if(!my.zero_ok && (bytes < 1)){ 
+  if (!my.zero_ok && (bytes < 1)) { 
     C->connection.reuse = 0; 
     socket_close(C); 
     http_free_headers(head); 
-    debug("zero bytes %s:%d", __FILE__, __LINE__);
+    debug("%s:%d zero bytes back from server", __FILE__, __LINE__);
     return FALSE; 
   } 
   stop     =  times(&t_stop); 
@@ -332,7 +340,7 @@ http_request(CONN *C, URL *U, CLIENT *client)
   client->time  += etime;
   client->code  += code;
   client->fail  += fail;
-  if(head->code == 200){
+  if (head->code == 200) {
     client->ok200++;
   }
 
@@ -342,7 +350,7 @@ http_request(CONN *C, URL *U, CLIENT *client)
   if (etime > highmark) {
     highmark = etime;
   }
-  if ( ( lowmark < 0 ) || ( etime < lowmark ) ) {
+  if ((lowmark < 0) || (etime < lowmark)) {
     lowmark = etime;
   }
   client->bigtime = highmark;
@@ -351,27 +359,28 @@ http_request(CONN *C, URL *U, CLIENT *client)
   /**
    * verbose output, print statistics to stdout
    */
-  if((my.verbose && !my.get) && (!my.debug)){
-    if(my.csv){
-      if(my.display)
-        printf("%s%s%4d,%s,%d,%6.2f,%7lu,%s,%d,%s\n",
+  if ((my.verbose && !my.get) && (!my.debug)) {
+    int color = __select_color(head->code);
+    if (my.csv) {
+      if (my.display)
+        DISPLAY(color, "%s%s%4d,%s,%d,%6.2f,%7lu,%s,%d,%s",
         (my.mark)?my.markstr:"", (my.mark)?",":"", client->id, head->head, head->code, 
         etime, bytes, (my.fullurl)?U->url:U->pathname, U->urlid, fmtime
       );
       else
-        printf("%s%s%s,%d,%6.2f,%7lu,%s,%d,%s\n",
+        DISPLAY(color, "%s%s%s,%d,%6.2f,%7lu,%s,%d,%s",
           (my.mark)?my.markstr:"", (my.mark)?",":"", head->head, head->code, 
           etime, bytes, (my.fullurl)?U->url:U->pathname, U->urlid, fmtime
         );
     } else {
-      if(my.display)
-        printf(
-          "%4d: %s %d %6.2f secs: %7lu bytes ==> %s\n", client->id,
+      if (my.display)
+        DISPLAY(
+          color, "%4d: %s %d %6.2f secs: %7lu bytes ==> %s", client->id,
           head->head, head->code, etime, bytes, (my.fullurl)?U->url:U->pathname
         ); 
       else
-        printf( 
-          "%s %d %6.2f secs: %7lu bytes ==> %s\n", 
+        DISPLAY ( 
+          color, "%s %d %6.2f secs: %7lu bytes ==> %s", 
           head->head, head->code, etime, bytes, (my.fullurl)?U->url:U->pathname
         );
     } /* else not my.csv */
@@ -380,27 +389,27 @@ http_request(CONN *C, URL *U, CLIENT *client)
   /**
    * close the socket and free memory.
    */
-  if(!my.keepalive){
+  if (!my.keepalive) {
     socket_close(C);
   }
  
   /**
    * deal with HTTP > 300 
    */
-  switch(head->code){
+  switch (head->code) {
     URL  *redirect_url; /* URL in redirection request */
     case 301:
     case 302:
       redirect_url = (URL*)xmalloc(sizeof(URL));
-      if(my.follow && head->redirect[0]){
-        debug("parsing redirection URL %s", head->redirect);
-        if(protocol_length(head->redirect) == 0){
+      if (my.follow && head->redirect[0]) {
+        debug("%s:%d parse redirection URL %s", __FILE__, __LINE__, head->redirect);
+        if (protocol_length(head->redirect) == 0) {
           memcpy(redirect_url, U, sizeof(URL));
           redirect_url->pathname = head->redirect;
         } else {
           redirect_url = add_url(head->redirect, U->urlid);
         }
-        if((http_request(C, redirect_url, client)) == FALSE)
+        if ((http_request(C, redirect_url, client)) == FALSE)
           return FALSE;
       }
       xfree(redirect_url);
@@ -410,20 +419,20 @@ http_request(CONN *C, URL *U, CLIENT *client)
        * WWW-Authenticate challenge from the WWW server
        */
       client->auth.www = (client->auth.www==0)?1:client->auth.www;
-      if((client->auth.bids.www++) < my.bids - 1){
-        if(head->auth.type.www == DIGEST){
+      if ((client->auth.bids.www++) < my.bids - 1) {
+        if (head->auth.type.www == DIGEST) {
           client->auth.type.www = DIGEST;
-	  if(set_digest_authorization(WWW, &(client->auth.wwwchlg), &(client->auth.wwwcred), &(client->rand_r_SEED), head->auth.realm.www, head->auth.challenge.www) < 0) {
+	  if (set_digest_authorization(WWW, &(client->auth.wwwchlg), &(client->auth.wwwcred), &(client->rand_r_SEED), head->auth.realm.www, head->auth.challenge.www) < 0) {
 	    fprintf(stderr, "ERROR from set_digest_authorization\n");
 	    return FALSE;
 	  }
           break; 
         }
-        if(head->auth.type.www == BASIC){
+        if (head->auth.type.www == BASIC) {
           client->auth.type.www =  BASIC;
           set_authorization(WWW, head->auth.realm.www);
         }
-        if((http_request(C, U, client)) == FALSE){
+        if ((http_request(C, U, client)) == FALSE) {
           fprintf(stderr, "ERROR from http_request\n");
           return FALSE;
         }
@@ -434,20 +443,20 @@ http_request(CONN *C, URL *U, CLIENT *client)
        * Proxy-Authenticate challenge from the proxy server.
        */
       client->auth.proxy = (client->auth.proxy==0)?1:client->auth.proxy;
-      if((client->auth.bids.proxy++) < my.bids - 1){
-        if(head->auth.type.proxy == DIGEST){
+      if ((client->auth.bids.proxy++) < my.bids - 1) {
+        if (head->auth.type.proxy == DIGEST) {
           client->auth.type.proxy =  DIGEST;
-	  if(set_digest_authorization(PROXY, &(client->auth.proxychlg), &(client->auth.proxycred), &(client->rand_r_SEED), head->auth.realm.proxy, head->auth.challenge.proxy) < 0) {
+	  if (set_digest_authorization(PROXY, &(client->auth.proxychlg), &(client->auth.proxycred), &(client->rand_r_SEED), head->auth.realm.proxy, head->auth.challenge.proxy) < 0) {
 	    fprintf(stderr, "ERROR from set_digest_authorization\n");
 	    return FALSE;
 	  } 
           break;
         }
-        if(head->auth.type.proxy == BASIC){
+        if (head->auth.type.proxy == BASIC) {
           client->auth.type.proxy = BASIC;
           set_authorization(PROXY, head->auth.realm.proxy);
         }
-        if((http_request(C, U, client)) == FALSE)
+        if ((http_request(C, U, client)) == FALSE)
           return FALSE;
       }
       break;
@@ -507,3 +516,55 @@ increment_failures()
   pthread_testcancel();
 }
 
+private int 
+__select_color(int code) 
+{
+  switch(code) {
+    case 200:
+    case 201:
+    case 202:
+    case 203:
+    case 204:
+    case 205:
+    case 206:
+      return BLUE;
+    case 300:
+    case 301:
+    case 302:
+    case 303:
+    case 304:
+    case 305:
+    case 306:
+    case 307:
+      return CYAN;
+    case 400: 
+    case 401: 
+    case 402: 
+    case 403: 
+    case 404: 
+    case 405: 
+    case 406: 
+    case 407: 
+    case 408: 
+    case 409: 
+    case 410: 
+    case 411: 
+    case 412: 
+    case 413: 
+    case 414: 
+    case 415: 
+    case 416: 
+    case 417: 
+      return MAGENTA;
+    case 500:
+    case 501:
+    case 502:
+    case 503:
+    case 504:
+    case 505:
+    default: // WTF?
+      return RED;
+  }
+  return RED;
+}
+
