@@ -59,7 +59,11 @@ typedef struct
   unsigned int   ok200;
   URL    **U;
   struct {
+    DIGEST_CHLG *wwwchlg;
+    DIGEST_CRED *wwwcred;
     int  www;
+    DIGEST_CHLG *proxychlg;
+    DIGEST_CRED *proxycred;
     int  proxy;
     struct {
       int  www;
