@@ -23,8 +23,9 @@
 #define HANDLER_H 
 
 #include <signal.h>
+#include <crew.h>
 
 void spin_doctor();
-void sig_handler( pthread_t * ); 
+void sig_handler(CREW crew); 
 
 #endif/*HANDLER_H*/
