@@ -25,7 +25,7 @@
 #include <stdlib.h>
 #include <data.h>
 
-void    log_transaction(DATA D, int failed);
+void    log_transaction(DATA D);
 void    write_to_log(int count, float elapsed, int bytes, float ttime, int code, int failed);
 void    mark_log_file(char *message); 
 BOOLEAN file_exists(char *file);
